import * as pulumi from "@pulumi/pulumi";
/**
 * The ``postgresql.Extension`` resource creates and manages an extension on a PostgreSQL
 * server.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const myExtension = new postgresql.Extension("my_extension", {name: "pg_trgm"});
 * ```
 *
 * ## Import
 *
 * PostgreSQL Extensions can be imported using the database name and the extension's resource name, e.g.
 *
 * ```sh
 * $ pulumi import postgresql:index/extension:Extension uuid_ossp example-database.uuid-ossp`
 * ```
 */
export declare class Extension extends pulumi.CustomResource {
    /**
     * Get an existing Extension resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ExtensionState, opts?: pulumi.CustomResourceOptions): Extension;
    /**
     * Returns true if the given object is an instance of Extension.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Extension;
    /**
     * When true, will also create any extensions that this extension depends on that are not already installed. (Default: false)
     */
    readonly createCascade: pulumi.Output<boolean | undefined>;
    /**
     * Which database to create the extension on. Defaults to provider database.
     */
    readonly database: pulumi.Output<string>;
    /**
     * When true, will also drop all the objects that depend on the extension, and in turn all objects that depend on those objects. (Default: false)
     */
    readonly dropCascade: pulumi.Output<boolean | undefined>;
    /**
     * The name of the extension.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Sets the schema of an extension.
     */
    readonly schema: pulumi.Output<string>;
    /**
     * Sets the version number of the extension.
     */
    readonly version: pulumi.Output<string>;
    /**
     * Create a Extension resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ExtensionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Extension resources.
 */
export interface ExtensionState {
    /**
     * When true, will also create any extensions that this extension depends on that are not already installed. (Default: false)
     */
    createCascade?: pulumi.Input<boolean>;
    /**
     * Which database to create the extension on. Defaults to provider database.
     */
    database?: pulumi.Input<string>;
    /**
     * When true, will also drop all the objects that depend on the extension, and in turn all objects that depend on those objects. (Default: false)
     */
    dropCascade?: pulumi.Input<boolean>;
    /**
     * The name of the extension.
     */
    name?: pulumi.Input<string>;
    /**
     * Sets the schema of an extension.
     */
    schema?: pulumi.Input<string>;
    /**
     * Sets the version number of the extension.
     */
    version?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Extension resource.
 */
export interface ExtensionArgs {
    /**
     * When true, will also create any extensions that this extension depends on that are not already installed. (Default: false)
     */
    createCascade?: pulumi.Input<boolean>;
    /**
     * Which database to create the extension on. Defaults to provider database.
     */
    database?: pulumi.Input<string>;
    /**
     * When true, will also drop all the objects that depend on the extension, and in turn all objects that depend on those objects. (Default: false)
     */
    dropCascade?: pulumi.Input<boolean>;
    /**
     * The name of the extension.
     */
    name?: pulumi.Input<string>;
    /**
     * Sets the schema of an extension.
     */
    schema?: pulumi.Input<string>;
    /**
     * Sets the version number of the extension.
     */
    version?: pulumi.Input<string>;
}
